from prettyqt.qt import QtCore


class CollatorSortKey(QtCore.QCollatorSortKey):
    pass
